Crate aya_metrics_common

Crate aya_metrics_common 

Provides common metric functionality for use in both user space and in BPF.

Enums

MeterKind
The kind of Meter.

Constants

BPF_COUNTERS_MAX_ENTRIES
The maximum number of counters that can be inserted the BPF per CPU array. Setting it to 64 is arbitrary and this should be generalized before releasing [aya-metrics-ebpf].

Traits

Counter
A trait which should be implemented over an enumeration defining counters in the same BPF map.
Meter
A base trait for all kinds of meters.