Provides common metric functionality for use in both user space and in BPF.
Enums
Constants
- BPF_
COUNTERS_ MAX_ ENTRIES - The maximum number of counters that can be inserted the BPF per CPU array. Setting it to 64 is arbitrary and this should be generalized before releasing [aya-metrics-ebpf].